@@ -7,6 +7,8 @@ CustomSlider::CustomSlider(QWidget *parent, int width, int height)
 	m_width = width;
 	m_height = height;
 
+        m_strText = "";
+
         this->setFixedSize(m_width, m_height);
 	m_bgcolor = QColor(0, 0, 0);
 	m_p1color = QColor(150, 150, 150);
@@ -21,11 +23,13 @@ CustomSlider::~CustomSlider()
 void CustomSlider::paintEvent(QPaintEvent *)
 {
 	QPainter painter(this);
+
 	painter.setRenderHint(QPainter::Antialiasing);
 
 	painter.setPen(Qt::NoPen);
 
-	painter.setBrush(m_p1color);
+        //painter.setBrush(m_p1color);
+        painter.setBrush(m_bgcolor);
 	painter.drawRect(QRect(0,0,m_width,m_height));
 
 	painter.setBrush(m_bgcolor);
@@ -36,6 +40,12 @@ void CustomSlider::paintEvent(QPaintEvent *)
 
 	painter.setBrush(m_p2color);
 	painter.drawRect(QRect(2,2,m_pos2,m_height-4));
+
+        if(m_strText!="")
+        {
+            painter.setPen(m_textColor);
+            painter.drawText(QRect(0,0,m_width-5,m_height),Qt::AlignRight|Qt::AlignVCenter,m_strText);
+        }
 }
 
 void CustomSlider::mousePressEvent(QMouseEvent *event)
@@ -74,3 +84,14 @@ void CustomSlider::setP2Color(QColor color)
 	m_p2color = color;
 	update();
 }
+void CustomSlider::setTextColor(QColor color)
+{
+    m_textColor = color;
+    update();
+}
+
+void CustomSlider::setText(const QString& txt)
+{
+    m_strText = txt;
+    update();
+}
