@@ -24,6 +24,7 @@
 #include <QMaemo5InformationBox>
 #include <QAction>
 #include <qspotify_src/spotifysession.h>
+#include <qspotify_src/imagecontainer.h>
 #include "CustomSlider.h"
 #include "SpectrumAnalyzer.h"
 #include "ListViewDelegate.h"
@@ -34,6 +35,9 @@
 #define SLIDER_WIDTH 355 //width of the custom progress slider widget
 #define SLIDER_HEIGHT 40 //height of the custom progress slider widget
 
+#define QUEUEVIEW_COVERART_WIDTH    355
+#define QUEUEVIEW_COVERART_HEIGHT   355
+
 #define QUEUEVIEW_ID 1
 
 class QueueView : public QMainWindow
@@ -62,12 +66,10 @@ private:
 
     QGridLayout m_PlayControls;
 
-    QLabel m_AlbumCoverContainer;
+    QLabel m_AlbumCover;
 
     QLabel m_ArtistName;
 
-    QImage m_AlbumCoverPic; //current album cover (for selected track)
-
     QPushButton m_PauseResumeBtn; //pause / resume
 
     QPushButton m_PrevBtn; //prev track
@@ -88,6 +90,8 @@ private:
 
     Spotify::Session* m_pSession; //Spotify session instance
 
+    Spotify::ImageContainer* m_pAlbumCoverContainer; //container for the album coverart image
+
     OssoWrapper* m_pOssoWrapper; //OssoWrapper instance pointer
 
     Spotify::Track* m_pCurrTrack; //currently playing track in queue
@@ -108,6 +112,8 @@ private:
 
     bool m_playing; //TRUE in case currently in playing state
 
+    bool m_currTrackScrobbled; //TRUE in case the current track has been scrobbled (to Last.fm)
+
     qint32 m_CallerID; //used as identifier to Spotify session calls that require caller ID
 
     QList<Spotify::Track*> m_PlayQueue; //current play queue
@@ -122,16 +128,17 @@ private:
 
     void clearViewSelection(); //clear the current view selection (i.e., set to state when no track is active)
 
-    void shuffleQueue(); //shuffle the current playqueue (the m_ShuffleQueue contains the shuffled queue positions)
+    void shuffleQueue(); //shuffle the current playqueue (the m_ShuffleQueue ctiontains the shuffled queue posions)
 
     void playTrack(Spotify::Track* track); //request to play (stream) specified track
 
-    void pausePlayback(); //request to pause music playback (and set the UI to corresponding state)
+    void pauseResumePlayback(); //request to pause / resume music playback (and set the UI to corresponding state)
 
     void setupContextMenu(); //set up the listview context menu
+
     void setupMenubar(); //set up the view menubar
 
-    void setListViewState(); //set current listview state
+    void setListViewState(); //set current listiew state
 
 
 
@@ -142,7 +149,7 @@ private slots:
     void OnShuffleToggle();
     void OnTrackBufferedAmountUpdated(qint32 bufferedAmount);
     void OnPlaybackPositionUpdated(qint64 playbackPos);
-    void OnAlbumCoverReady(QImage image, qint32 callerID);
+    void OnAlbumCoverLoaded();
     void OnTrackPlaybackFinished();
     void OnPlayingState(bool state);
     void OnNextTrackBtn();
@@ -152,6 +159,7 @@ private slots:
     void OnPlaybackStateChangeRequest(enum pb_state_e requestedState);
     void OnViewAlbumAction();
     void OnPlayAlbumAction();
+    void OnViewArtistAction();
     void OnAlbumBrowseReady(Spotify::AlbumBrowser* browser, qint32 callerID);
 
 signals:
@@ -159,6 +167,10 @@ signals:
     void playQueuePosUpdated(qint32); //signal emitted when position in playqueue has been updated
     void showFMTransmitterDialog(); //signal emitted upon request to show the FM Transmitter control panel plugin
     void showAlbumView(Spotify::Album*); //request to show the album view for the specified album
+    void showArtistView(Spotify::Artist*); //request to show the artist view for the specified artist
+    void updateNowPlaying(const QString& strTrackName, const QString& strArtistName, const QString& strAlbumName, const QString& strAlbumArtist); //request to update the client Last.fm 'now playing' status
+    void scrobbleTrack(); //request to scrobble current track to Last.fm
+    void playQueueSet(const QList<Spotify::Track*>&); //signal emitted upon new playqueue set
 };
 
 #endif // QUEUEVIEW_H
