@@ -54,8 +54,7 @@ void TrackView::setupContextMenu()
     connect(pViewAlbumAct,SIGNAL(triggered()),SLOT(OnViewAlbumAction()));
     m_pTrackListView->addAction(pViewAlbumAct);
     QAction* pViewArtistAct = new QAction(tr("Browse Artist"),this);
-    pViewArtistAct->setEnabled(false);
-    //connect(pPlayAlbumAct,SIGNAL(triggered()),SLOT(OnViewArtistAction()));
+    connect(pViewArtistAct,SIGNAL(triggered()),SLOT(OnViewArtistAction()));
     m_pTrackListView->addAction(pViewArtistAct);
 }
 
@@ -120,6 +119,21 @@ void TrackView::OnPlayAlbumAction()
     }
 }
 
+void TrackView::OnViewArtistAction()
+{
+    //Request to show Artist View for currently selected artist.
+
+    Spotify::Track* track = getTrackFromModelIndex(m_pTrackListView->currentIndex());
+
+    if(track)
+    {
+        if(track->getArtist())
+        {
+            emit showArtistView(track->getArtist());
+        }
+    }
+}
+
 void TrackView::OnAlbumBrowseReady(Spotify::AlbumBrowser* browser, qint32 callerID)
 {
     //notification that album browse request completed
@@ -407,6 +421,24 @@ void TrackView::keyPressEvent(QKeyEvent *evt)
         close(); //hide the view
         evt->accept();
     }
+    else if(evt->key()==Qt::Key_M)
+    {
+        //set sorting order to most popular
+        if(m_pSortByAct->getCurrentSelection()!=1)
+        {
+            m_pSortByAct->setCurrentSelection(1); //set sorting to Most popular
+            if(m_pPlaylist)
+            { //playlist view
+                m_pPlaylist->sortByPopularity();
+                addTracks(m_pPlaylist);
+            }
+            else
+            { //search results view
+                qSort(m_TrackList.begin(),m_TrackList.end(),tracksByPopularityDesc);
+                addTracks(m_TrackList);
+            }
+        }
+    }
     else
     {
         QMainWindow::keyPressEvent(evt);
