@@ -23,6 +23,15 @@ MainWindow::MainWindow(QWidget *parent)
         m_pOssoWrapper->requestPlaybackStateChange(PB_STATE_STOP); //request to enter initial stopped state
     }
 
+    m_pLastFMScrobbler = new LastFMScrobbler(this); //allocate Last.fm scrobbler instance
+    m_pLastFMScrobbler->setAPIKey("f950a6e7870997ea77cb0ecc9c8fb962"); //set associated Last.fm API key
+    m_pLastFMScrobbler->setSecret("48875d761d06f7b0efd37304e0226e9f"); //set associated Last.fm shared secret
+    m_pLastFMScrobbler->setUserAgent("QSpot " + QString(APP_VERSION)); //set client user agent
+    m_pLastFMScrobbler->setCachePath("/home/user/");
+    connect(m_pLastFMScrobbler,SIGNAL(authenticateSessionStatus(bool,const QString&)),SLOT(OnScrobblingStatus(bool, const QString&)));
+    connect(m_pLastFMScrobbler,SIGNAL(updateNowPlayingStatus(bool,const QString&)),SLOT(OnScrobblingStatus(bool, const QString&)));
+    connect(m_pLastFMScrobbler,SIGNAL(scrobbleTracksStatus(bool,const QString&)),SLOT(OnScrobblingStatus(bool, const QString&)));
+
     m_pTimeoutTimer  = new QTimer(this); //timeout timer instance
     connect(m_pTimeoutTimer,SIGNAL(timeout()),SLOT(OnPlaylistLoadingTimeout()));
 
@@ -44,14 +53,23 @@ MainWindow::MainWindow(QWidget *parent)
     connect(m_pTrackView,SIGNAL(playQueueSet(const QList<Spotify::Track*>&)),SLOT(OnSetPlayQueue(const QList<Spotify::Track*>&)));
     connect(m_pTrackView,SIGNAL(showFMTransmitterDialog()),SLOT(OnDisplayFMTransmitterDialog()));
     connect(m_pTrackView,SIGNAL(showAlbumView(Spotify::Album*)),SLOT(OnShowAlbumView(Spotify::Album*)));
+    connect(m_pTrackView,SIGNAL(showArtistView(Spotify::Artist*)),SLOT(OnShowArtistView(Spotify::Artist*)));
 
     m_pAlbumView = new AlbumView(m_pSession,m_pTrackView);
     connect(m_pAlbumView,SIGNAL(playQueueSet(const QList<Spotify::Track*>&)),SLOT(OnSetPlayQueue(const QList<Spotify::Track*>&)));
 
     m_pQueueView = new QueueView(m_pSession,m_pOssoWrapper,this); //initial parent set to current instance
     connect(m_pQueueView,SIGNAL(playQueuePosUpdated(qint32)),SLOT(OnPlayQueuePosUpdated(qint32)));
+    connect(m_pQueueView,SIGNAL(playQueueSet(QList<Spotify::Track*>)),SLOT(OnSetPlayQueue(QList<Spotify::Track*>)));
     connect(m_pQueueView,SIGNAL(showFMTransmitterDialog()),SLOT(OnDisplayFMTransmitterDialog()));
     connect(m_pQueueView,SIGNAL(showAlbumView(Spotify::Album*)),SLOT(OnShowAlbumView(Spotify::Album*)));
+    connect(m_pQueueView,SIGNAL(showArtistView(Spotify::Artist*)),SLOT(OnShowArtistView(Spotify::Artist*)));
+    connect(m_pQueueView,SIGNAL(updateNowPlaying(const QString&,const QString&,const QString&,const QString&)),SLOT(OnScrobbleUpdateNowPlaying(const QString&, const QString&, const QString&, const QString&)));
+    connect(m_pQueueView,SIGNAL(scrobbleTrack()),SLOT(OnScrobbleTrack()));
+
+
+    m_pArtistView = new ArtistView(m_pSession,m_pTrackView);
+    connect(m_pArtistView,SIGNAL(showAlbumView(Spotify::Album*)),SLOT(OnShowAlbumView(Spotify::Album*)));
 
     //init the playlist listview instance
     m_pPlaylistView = new QListView(this);
@@ -165,6 +183,13 @@ void MainWindow::OnSettingsSaved()
     {
         m_pSession->setPreBufferingActive(false);
     }
+
+    if(m_pAppSettings->value("QSpot/enableScrobbling",ENABLE_SCROBBLING_DEFAULT).toInt())
+    {
+        //scrobbling enabled, send authentication request in order to retrieve a Last.fm session key
+        m_pLastFMScrobbler->setCache(true); //enable caching of scrobbles
+        m_pLastFMScrobbler->authenticateSession(m_pAppSettings->value("QSpot/lastfmUid","").toString(),m_pAppSettings->value("QSpot/lastfmPwd","").toString());
+    }
 }
 
 void MainWindow::OnShowLogin()
@@ -197,7 +222,9 @@ void MainWindow::OnPlaybackPositionUpdated(qint64 pos)
 
         QTextStream outStream(&strCurrTrackProgressInfo);
 
-        QTime currTrackPos(pos/3600000,pos/60000,(pos/1000)%60,0);
+        int seconds = ( pos / 1000);
+        QTime currTrackPos = QTime( 0, 0, 0, 0 );
+        currTrackPos = currTrackPos.addSecs( seconds );
 
         Spotify::Track* currTrack = m_PlayQueue.at(m_currQueuePos);
 
@@ -239,7 +266,7 @@ void MainWindow::OnNowPlaying()
         if(m_pQueueView)
         {
             if(m_pQueueView->parent()!=this)
-                m_pQueueView->setParent(this,m_pQueueView->windowFlags()); //re-parent QueueView instance (parent set to current instance)
+                m_pQueueView->setParent(this,m_pQueueView->windowFlags()); //re-parent the QueueView instance (to this instance)
             m_pQueueView->show();
         }
     }
@@ -249,29 +276,28 @@ void MainWindow::OnSetPlayQueue(const QList<Spotify::Track*>& queue)
 {
     //set the current (active) playqueue to be
     m_PlayQueue = queue;
-    if(sender()!=m_pAlbumView)
-    {
-        if(m_pQueueView->parent()!=sender())
-            m_pQueueView->setParent((QWidget*)sender(),m_pQueueView->windowFlags()); //re-parent the QueueView instance (to sender instance)
-    }
-    else
-    {
-        if(m_pQueueView->parent()!=m_pTrackView)
-            m_pQueueView->setParent(m_pTrackView,m_pQueueView->windowFlags()); //re-parent the QueueView instance (to TrackView instance)
-
-    }
     m_pQueueView->setQueueInitialState(m_PlayQueue);
+    if(m_pArtistView->isVisible())
+        m_pArtistView->hide();
     m_pQueueView->show();
 }
 
-void MainWindow::OnShowAlbumView(Spotify::Album* album)
+void MainWindow::OnShowAlbumView(Spotify::Album* pAlbum)
 {
     //show the Album View for the specified album
-    //m_pAlbumView->setParent((QWidget*)sender(),m_pAlbumView->windowFlags()); //re-parent the Album View instance (to sender instance)
-    m_pAlbumView->setAlbum(album);
+    if(sender()==m_pTrackView && m_pQueueView->parent()!=m_pTrackView)
+        m_pQueueView->setParent(m_pTrackView,m_pQueueView->windowFlags()); //re-parent the QueueView instance (to TrackView instance)
+    m_pAlbumView->setAlbum(pAlbum);
     m_pAlbumView->showMaximized();
 }
 
+void MainWindow::OnShowArtistView(Spotify::Artist* pArtist)
+{
+    //show the Artist View for the specified artist
+    m_pArtistView->showMaximized();
+    m_pArtistView->setArtist(pArtist);
+}
+
 void MainWindow::OnPlayQueuePosUpdated(qint32 pos)
 {
      if(pos>=0)
@@ -348,16 +374,11 @@ void MainWindow::OnPlaylistLoadingTimeout()
     if(m_pSession->playlistLoadingInProgress())
     {
         m_pSession->stopPlaylistLoading(); //interrupt playlist loading
-
-        QMaemo5InformationBox::information(this,tr("Timeout occured while loading playlists!")); //display timeout notification
-
-        if(!m_AudioInit)
-        {
-            m_pSession->initAudio(); //init audio interface
-            m_pSession->setMinBufferSize(m_pAppSettings->value("QSpot/minBufferLen",MIN_BUFFER_LEN_DEFAULT).toInt()); //update min. buffer length (default to 30 secs)
-            m_AudioInit = true;
-        }
     }
+
+    QMaemo5InformationBox::information(this,tr("Timeout occured while loading playlists!")); //display timeout notification
+
+    setupInitialState();
 }
 
 void MainWindow::OnPlaylistContainersReady(QList<Spotify::Playlist*> playlists)
@@ -392,17 +413,30 @@ void MainWindow::OnPlaylistContainersReady(QList<Spotify::Playlist*> playlists)
    m_SearchInput.setFocus(); //set initial (default) focus to the Search input field
    m_SearchBtn.setDisabled(false);
 
-   if(!m_AudioInit)
-   {
-      m_pSession->initAudio(); //init audio interface
-      m_pSession->setMinBufferSize(m_pAppSettings->value("QSpot/minBufferLen",MIN_BUFFER_LEN_DEFAULT).toInt()); //update min. buffer length (default to 30 secs)
-       m_AudioInit = true;
-   }
-
+   setupInitialState();
 
    setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false);
 }
 
+void MainWindow::setupInitialState()
+{
+    //set up the app initial state (audio etc.)
+
+    if(!m_AudioInit)
+    {
+       m_pSession->initAudio(); //init audio interface
+       m_pSession->setMinBufferSize(m_pAppSettings->value("QSpot/minBufferLen",MIN_BUFFER_LEN_DEFAULT).toInt()); //update min. buffer length (default to 30 secs)
+       m_AudioInit = true;
+       if(m_pAppSettings->value("QSpot/enableScrobbling",ENABLE_SCROBBLING_DEFAULT).toInt())
+       {
+           //scrobbling enabled, authenticate user to retrieve session key
+           m_pLastFMScrobbler->setCache(true); //enable caching of scrobbles
+           m_pLastFMScrobbler->authenticateSession(m_pAppSettings->value("QSpot/lastfmUid","").toString(),m_pAppSettings->value("QSpot/lastfmPwd","").toString());
+       }
+    }
+
+}
+
 void MainWindow::OnPlaylistActivated(QModelIndex index)
 {
 	//Display the trackview for the activated playlist
@@ -413,6 +447,11 @@ void MainWindow::OnPlaylistActivated(QModelIndex index)
 
         if(m_pTrackView)
         {
+            if(m_pQueueView)
+            {
+                if(m_pQueueView->parent()!=m_pTrackView)
+                    m_pQueueView->setParent(m_pTrackView,m_pQueueView->windowFlags());//re-parent QueueView instance (to TrackView)
+            }
             m_pTrackView->setPlaylist(pPlaylist); //set active playlist for track view
             m_pTrackView->show();
         }
@@ -486,6 +525,11 @@ void MainWindow::OnSearchComplete(Spotify::Search* search)
             {//some track / tracks returned by search
                 if(m_pTrackView)
                 {
+                    if(m_pQueueView)
+                    {
+                        if(m_pQueueView->parent()!=m_pTrackView)
+                            m_pQueueView->setParent(m_pTrackView,m_pQueueView->windowFlags()); //re-parent QueueView (to TrackView)
+                    }
                     m_pTrackView->setSearchResults(search);
                     m_pTrackView->show();
                 }
@@ -509,5 +553,31 @@ void MainWindow::OnPlaybackTokenLost()
      QMaemo5InformationBox::information(this,tr("Playback paused due to the same account being used somewhere else!"));
 }
 
+void MainWindow::OnScrobblingStatus(bool status, const QString& error)
+{
+    //status received from the Last.fm service
+
+    if(!status)
+    {
+        //error occured
+        QMaemo5InformationBox::information(this,tr("Last.fm error: ") + error);
+    }
+}
+
+void MainWindow::OnScrobbleUpdateNowPlaying(const QString& strTrackName, const QString& strArtistName, const QString& strAlbumName, const QString& strAlbumArtist)
+{
+    //update Last.fm now playing info
+    if(m_pAppSettings->value("QSpot/enableScrobbling",ENABLE_SCROBBLING_DEFAULT).toInt()) //scrobbling enabled
+        m_pLastFMScrobbler->updateNowPlaying(strTrackName,strArtistName,strAlbumName,strAlbumArtist);
+}
+
+void MainWindow::OnScrobbleTrack()
+{
+    //scrobble current track to Last.fm (and send current queue of scrobbles to Last.fm)
+     if(m_pAppSettings->value("QSpot/enableScrobbling",ENABLE_SCROBBLING_DEFAULT).toInt()) //scrobbling enabled
+        m_pLastFMScrobbler->scrobbleTrack();
+}
+
+
 
 
