@@ -70,8 +70,8 @@ void PlaybackThread::run()
    //thread main loop
 
     QByteArray buffer;
-    qint32 nextTrackStartPos;
     int error = 0;
+    bool playbackStateChanged = true;
 
     forever
     {
@@ -106,16 +106,21 @@ void PlaybackThread::run()
 
         if(!m_FIFO.isEmpty() && !m_playbackPaused)
         { //data in audio FIFO and playback has not been paused
-            emit playing(true);
-            buffer = m_FIFO.takeFirst();
+            if(playbackStateChanged)
+            { //playback state changed to playing
+                emit playing(true);
+                playbackStateChanged = false;
+            }
+
+            buffer = m_FIFO.first();
+            m_FIFO.pop_front();
+            m_FIFO.squeeze();
             m_FIFOSize -= buffer.size();
             if(m_preBufActive && !m_trackStartPosList.isEmpty())
             {
                 if(m_trackStartPosList.first()>0)
-                {
-                    nextTrackStartPos = m_trackStartPosList.takeFirst();
-                    nextTrackStartPos--;
-                    m_trackStartPosList.prepend(nextTrackStartPos);
+                { //decrement the list item values to take into account that FIFO length has changed
+                    updateTrackStartPositions();
                 }
             }
 
@@ -135,12 +140,16 @@ void PlaybackThread::run()
 
         }
         else
-        {
-          emit playing(false);
+        { //playback state changed to paused / stopped
+          if(!playbackStateChanged)
+          {
+            emit playing(false);
+            playbackStateChanged = true;
+           }
           m_audio_mutex.unlock(); //release lock
         }
 
-        msleep(20); //sleep for a while
+        msleep(100); //sleep for a while
     }
 }
 
@@ -158,6 +167,8 @@ void PlaybackThread::FIFOAppend(const QByteArray& buffer)
 void PlaybackThread::clearFIFO()
 {
     m_FIFO.clear();
+    m_FIFO.squeeze();
+    m_FIFO.reserve(m_minBufferSize+5);
 }
 
 qint32 PlaybackThread::getFIFOSize()
@@ -200,6 +211,7 @@ void PlaybackThread::setMinBufferSize(qint32 secs)
 {
     //set min. FIFO buffer size (in secs)
     m_minBufferSize = secs;
+    m_FIFO.reserve(m_minBufferSize+5); //reserve a suitable sized FIFO in advance
 }
 
 qint32 PlaybackThread::getMinBufferSize()
@@ -214,6 +226,7 @@ void PlaybackThread::setPreBufActive(bool active)
 
 void PlaybackThread::setNextTrackStartPos()
 {
+    //Assigns the starting position of new track audio data in the buffer (to the end of the current FIFO).
     m_trackStartPosList.append(m_FIFO.count());
 }
 
@@ -228,6 +241,19 @@ void PlaybackThread::setNextTrackStartPos(qint32 pos)
         m_trackStartPosList.clear();
 }
 
+
+void PlaybackThread::updateTrackStartPositions()
+{
+    //Private method iterating through the track start positions list and updating the start positions as elements are removed from the FIFO.
+
+    QList<qint32>::iterator it;
+
+    for(it = m_trackStartPosList.begin(); it != m_trackStartPosList.end(); ++it)
+    {
+        *it -= 1; //decrement the item value
+    }
+}
+
 void PlaybackThread::setNewTrackStarted(bool started)
 {
     m_newTrackStarted = started;
