@@ -9,7 +9,7 @@ namespace Spotify
     class Session;
     class Artist;
     class Link;
-    class Album: public QObject, public Spotify::ImageContainer
+    class Album: public QObject
     {
         Q_OBJECT
 
@@ -28,13 +28,10 @@ namespace Spotify
             QString getName() const { return m_name; }
             int getYear() const { return m_year; }
             Spotify::Album::Type type() const { return m_type; }
-            virtual QString getTypeName() { return "Album Cover Container"; }
-            void loadCoverArt();
+            QString getTypeName();
+            QString getCategory();
             ~Album();
 
-            // From ImageContainer:
-            virtual void setImage( QImage image );
-
             static Spotify::Album* fromLink( Spotify::Link& link, QObject* parent = 0 );
 
         signals:
@@ -55,6 +52,10 @@ namespace Spotify
             bool m_hasRef;
     };
 
+
 } // namespace Spotify
 
+//compare non-members (for sorting)
+ bool albumsByTypeYearDesc(Spotify::Album*, Spotify::Album*);
+
 #endif // ALBUM_H
