@@ -60,6 +60,8 @@ Spotify::Session::Session( QObject* parent ):
 
     connect(this, SIGNAL(onAlbumBrowserReady(sp_albumbrowse*,qint32*)),
                     this, SLOT(OnAlbumBrowserReady(sp_albumbrowse*,qint32*)),Qt::QueuedConnection);
+    connect(this, SIGNAL(onArtistBrowseComplete(sp_artistbrowse*)),
+                    this, SLOT(OnArtistBrowseComplete(sp_artistbrowse*)),Qt::QueuedConnection);
     m_pAudioThread = NULL;
 
     m_preBufActive = true;
@@ -227,7 +229,7 @@ Spotify::Error Spotify::Session::login( QString username, QString password )
 
     m_DisableNotifyThread = false;
 
-    m_error = sp_session_login( m_session, username.toAscii(), password.toAscii() );
+    m_error = sp_session_login( m_session, username.toUtf8(), password.toUtf8() );
     if( m_error.isError() )
     {
         qDebug()<<"Not valid";
@@ -389,7 +391,7 @@ Spotify::Error Spotify::Session::stop()
     return error;
 }
 
-void Spotify::Session::pausePlayback()
+void Spotify::Session::pauseResumePlayback()
 {
     //Pause / resume playback from Spotify (e.g., signal to playback thread to stop / continue writing data to PulseAudio)
     m_pAudioThread->getMutex()->lock();
@@ -443,27 +445,23 @@ Spotify::Error Spotify::Session::search( const QString& query, const int trackOf
     return error;
 }
 
-Spotify::Error Spotify::Session::getAlbumCover( Spotify::Album* album, qint32* pCallerID)
+Spotify::Error Spotify::Session::loadImage(const byte* imageID, Spotify::ImageContainer* pContainer)
 {
+    //request to load image (identified by imageID) from the Spotify backend.
+
     Spotify::Error error;
-    if( album && album->getCover() != 0 )
+    if( imageID && pContainer )
     {
-        sp_image* image = sp_image_create( m_session, album->getCover() );
+        sp_image* image = sp_image_create( m_session, imageID );
         error = sp_image_error( image );
-        Spotify::ImageContainer* ic = dynamic_cast< Spotify::ImageContainer* >( album );
-        sp_image_add_load_callback( image, &Spotify::Session::imageLoadedCallback, (void*)pCallerID );
+        if(image)
+            sp_image_add_load_callback( image, &Spotify::Session::imageLoadedCallback, (void*)pContainer );
     }
     else
         error = SP_ERROR_RESOURCE_NOT_LOADED;
     return error;
 }
 
-/*Spotify::Error Spotify::Session::getAlbumCover( Spotify::Track* track )
-{
-    return getAlbumCover( track->getAlbum() );
-}
-*/
-
 void Spotify::Session::getPlaylistContainer()
 {
     //Request (root) playlist container
@@ -651,24 +649,25 @@ void Spotify::Session::searchDeletedSlot( QObject* object )
         qDebug() << "WARNING: Trying to delete non-existing search";
 }
 
-Spotify::Error Spotify::Session::browse( Spotify::Artist* artist )
+bool Spotify::Session::browse( Spotify::Artist* artist )
 {
-    Spotify::Error error;
     if( artist )
     {
         sp_artist* spartist = artist->getArtist();
         sp_artistbrowse* ab = sp_artistbrowse_create( m_session, spartist,
                                                       &Spotify::Session::artistBrowseCompleteCallback,
                                                       NULL);
-        error = sp_artistbrowse_error( ab );
+        if(!ab)
+           return false;
         Spotify::ArtistCatalogue* ac = new Spotify::ArtistCatalogue( ab, this );
         m_artistBrowseHash.insert( ab, ac );
         connect( ac, SIGNAL(destroyed(QObject*)),
                  this, SLOT(artistCatalogueDeletedSlot(QObject*)));
     }
     else
-        error = SP_ERROR_RESOURCE_NOT_LOADED;
-    return error;
+        return false;
+
+    return true;
 }
 
 void Spotify::Session::artistCatalogueDeletedSlot( QObject* object )
@@ -737,7 +736,12 @@ void Spotify::Session::artistBrowseCompleteCallback( sp_artistbrowse* ab, void*
 
 void Spotify::Session::artistBrowseCompleteWrapper( sp_artistbrowse* ab, void* userdata )
 {
-    Q_UNUSED( userdata );
+    Q_UNUSED(userdata);
+    emit onArtistBrowseComplete(ab);
+}
+
+void Spotify::Session::OnArtistBrowseComplete( sp_artistbrowse* ab )
+{
     if( ab && m_artistBrowseHash.contains( ab ) )
     {
         qDebug() << "An artist was just browsed!";
@@ -1122,10 +1126,10 @@ void Spotify::Session::OnImageLoaded(sp_image* image, void* userdata)
         return;
     }
 
-    // Get data:
+    // Get actual image data
     data = (uchar*)sp_image_data(image,&len);
 
-    // Create QImage instance, for wrapping image data
+    // Create QImage instance, for wrapping the image data
 
     QImage img;
 
@@ -1134,18 +1138,16 @@ void Spotify::Session::OnImageLoaded(sp_image* image, void* userdata)
         qDebug() << "Loading of image data failed!";
     }
 
-
-    // Release sp_image:
-    sp_image_release(image);
-
-    qint32 callerID = -1;
-
     if(userdata)
-    {
-      callerID = *(qint32*)userdata;
+    { //assign image to associated container
+        Spotify::ImageContainer* pContainer = (Spotify::ImageContainer*)userdata;
+        pContainer->setImage(img);
     }
 
-    emit coverArtReady(img, callerID);
+    // Release sp_image
+    sp_image_release(image);
+
+    //emit coverArtReady(img, callerID);
 }
 
 void Spotify::Session::searchCompleteCallback( sp_search* search, void* userdata )
