@@ -304,3 +304,22 @@ bool tracksByPopularityDesc(Spotify::Track* track1, Spotify::Track* track2)
     return false;
 }
 
+bool tracksByDiscIndexAsc(Spotify::Track* track1, Spotify::Track* track2)
+{
+    //compare track instances first by disc (album), then by track index (ascending)
+
+    if(track1 && track2)
+    {
+        if(track1->getDisc()==track2->getDisc())
+        {
+            return(track1->getIndex()<track2->getIndex());
+        }
+        else
+        {
+            return(track1->getDisc()<track2->getDisc());
+        }
+    }
+
+    return false;
+}
+
